cumulusci.robotframework package
================================

Subpackages
-----------

.. toctree::

    cumulusci.robotframework.pageobjects

Submodules
----------

cumulusci.robotframework.CumulusCI module
-----------------------------------------

.. automodule:: cumulusci.robotframework.CumulusCI
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.Salesforce module
------------------------------------------

.. automodule:: cumulusci.robotframework.Salesforce
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.locators\_45 module
--------------------------------------------

.. automodule:: cumulusci.robotframework.locators_45
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.locators\_46 module
--------------------------------------------

.. automodule:: cumulusci.robotframework.locators_46
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.utils module
-------------------------------------

.. automodule:: cumulusci.robotframework.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.robotframework
    :members:
    :undoc-members:
    :show-inheritance:
